#!/bin/sh

. /var/packages/HighAvailability/target/etc/rc.subr

wait_remote_reboot()
{
	synoha_log notice "start to reboot remote"
	if ! synowebapi --exec api=SYNO.SHA.Panel.Action method=reboot_passive mode=reboot_passive version=1; then
		synoha_log notice "failed to reboot remote"
		return 1
	fi


	if ! wait_for "! ping -c 1 -w 2 $DRBD_IP_REMOTE" 600; then
		return 1
	fi

	synoha_log notice "start to wait remote online"
	if ! wait_for "test \"Passive\" = \"\$(synoha --remote-role)\"" 60 10; then
		synoha_log err "wait remote passive finish timeout. remote role : $(synoha --remote-role)"
		return 1
	fi

	return 0
}

case $1 in
	--sdk-mod-ver)
		#Print SDK support version
		echo "1.0";
		;;
	--name)
		#Print package name
		echo "Synology High-Availability"
		;;
	--pkg-ver)
		#Print package version
		echo "1.0";
		;;
	--vendor)
		#Print package vendor
		echo "Synology";
		;;
	--pre)
		if [ "Active" = "$(synoha --local-role)" ] && /usr/local/bin/synoha --remote-status | cut -d':' -f2 | grep -e online -e warning_online && ! is_support_xa  ; then
			synoha --expand-unalloc-check "$SPACE_PATH"
			ret=$?

			if [ $ret = 3 ];then
				synoha_log err "remote data size is larger than local"
				exit 1
			fi

			if [ $ret = 2 ];then
				synoha_log err "remote remain size isn't enough for expand"
				exit 1
			fi

			if [ $ret = 1 ]; then
				synoha_log notice "start to align partition"
				if ! synohaspace --align_partition "$SPACE_PATH"; then
					synoha_log err "fail to align partition"
					exit 1
				fi

				if ! wait_remote_reboot; then
					exit 1
				fi
			fi
		fi
		;;
	--post)
		if synohacore --is_ha_running && ! is_support_xa ; then
			if ! synoha --dump-disk-info; then
				synoha_log err "Failed to dump disk info"
			fi
		fi
		;;
	*)
		echo "Usage: $0 --sdk-mod-ver|--name|--pkg-ver|--vendor|--pre|--post|"
		;;
esac

