#!/bin/sh
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

HAISRUNNING=$(synogetkeyvalue /etc/synoinfo.conf runha)

OUTPUT_DIR="$1"

if [ "yes" != "$HAISRUNNING" ]; then
	mkdir -p "${OUTPUT_DIR}"
	touch ${OUTPUT_DIR}/ha_not_running
	exit 0
fi

# output directory is missing
if [ -z "${OUTPUT_DIR}" ]; then
	return
fi
mkdir -p "${OUTPUT_DIR}"

SYNOHA=/var/packages/HighAvailability/target/sbin/synoha
if $SYNOHA --local-role | grep -q "Active"; then
        $SYNOHA --collect-remote-debug-log "${OUTPUT_DIR}/passive_debug.dat"
fi

cat /proc/drbd > "${OUTPUT_DIR}/proc.drbd"
crm_mon -1 > "${OUTPUT_DIR}/crm.status"
crm configure show > "${OUTPUT_DIR}/crm.configure"

rsync -a \
	--exclude='confsync/rsync.pw' \
	--exclude='confsync/rsyncd.secrets' \
	--exclude='corosync/authkey' \
	/usr/syno/etc/packages/HighAvailability/ "${OUTPUT_DIR}/"

cp -r /var/lib/ha/* "${OUTPUT_DIR}"
if [ -f "${OUTPUT_DIR}/passive_debug.dat" ] || $SYNOHA --local-role | grep -q "Passive"; then
	# No need to collect remote logs if there is passive_debug.dat
	rm -rf "${OUTPUT_DIR}/remote_logs"
fi
ls -l /tmp/ha > "${OUTPUT_DIR}/tmp.ha.ls"
corosync-cfgtool -s > "${OUTPUT_DIR}/corosync-cfgtool"
corosync-cpgtool > "${OUTPUT_DIR}/corosync-cpgtool"
corosync-objctl > "${OUTPUT_DIR}/corosync-objctl"

if [ -f "${OUTPUT_DIR}/sync/synoha.db" ]; then
	/usr/bin/sqlite3 "${OUTPUT_DIR}/sync/synoha.db" \
	"SELECT level, datetime(time,'unixepoch','localtime'), username, msg FROM logs" \
	| sed -e 's/|/ /g' | sed -e 's/-/\//g' > "${OUTPUT_DIR}/synoha_db.log"
fi

exit 0
